@@ -68,9 +68,9 @@ class KCategoryDrawer;
 class KITEMVIEWS_EXPORT KCategorizedView : public QListView
 {
     Q_OBJECT
-    Q_PROPERTY(int categorySpacing READ categorySpacing WRITE setCategorySpacing)
-    Q_PROPERTY(bool alternatingBlockColors READ alternatingBlockColors WRITE setAlternatingBlockColors)
-    Q_PROPERTY(bool collapsibleBlocks READ collapsibleBlocks WRITE setCollapsibleBlocks)
+    Q_PROPERTY(int categorySpacing READ categorySpacing WRITE setCategorySpacing NOTIFY categorySpacingChanged)
+    Q_PROPERTY(bool alternatingBlockColors READ alternatingBlockColors WRITE setAlternatingBlockColors NOTIFY alternatingBlockColorsChanged)
+    Q_PROPERTY(bool collapsibleBlocks READ collapsibleBlocks WRITE setCollapsibleBlocks NOTIFY collapsibleBlocksChanged)
 
 public:
     KCategorizedView(QWidget *parent = nullptr);
@@ -196,6 +196,11 @@ public:
      */
     void reset() override;
 
+Q_SIGNALS:
+    void categorySpacingChanged(int spacing);
+    void alternatingBlockColorsChanged(bool enable);
+    void collapsibleBlocksChanged(bool enable);
+
 protected:
     /**
      * Reimplemented from QWidget.
